;**********************************************************************
;   This file is a basic code template for assembly code generation   *
;   on the PIC12F508. This file contains the basic code               *
;   building blocks to build upon.                                    *
;                                                                     *
;   Refer to the MPASM User's Guide for additional information on     *
;   features of the assembler (Document DS33014).                     *
;                                                                     *
;   Refer to the respective PIC data sheet for additional             *
;   information on the instruction set.                               *
;                                                                     *
;**********************************************************************
;                                                                     *
;    Filename:	    DRUM.asm                                          *
;    Date:          June 2, 2010                                      *
;    File Version:    A                                               *
;                                                                     *
;    Author: RON NEWTON                                               *
;    Company:                                                         *
;                                                                     * 
;                                                                     *
;**********************************************************************
;                                                                     *
;    Files Required: P12F508.INC                                      *
;                                                                     *
;**********************************************************************
;                                                                     *
;    Notes:                                                           *
;                                                                     *
;**********************************************************************

	list      p=12F508            ; list directive to define processor
	#include <p12F508.inc>        ; processor specific variable definitions

	__CONFIG   _MCLRE_OFF & _CP_OFF & _WDT_OFF & _IntRC_OSC

; '__CONFIG' directive is used to embed configuration word within .asm file.
; The lables following the directive are located in the respective .inc file. 
; See respective data sheet for additional information on configuration word.




;***** VARIABLE DEFINITIONS
REPEAT	EQU     0x07        ;example variable definition
DELAY1	EQU		0X08
DELAY2	EQU		0X09
FLAG	EQU		0X0A

#DEFINE		RED		GPIO,0			;LOCATIONS LED ON PINS
#DEFINE		GREEN	GPIO,1
#DEFINE		YELLOW	GPIO,2
#DEFINE		WHITE	GPIO,5
#DEFINE		DRUM	GPIO,3


;**********************************************************************
	ORG     0x1FF             ; processor reset vector

; Internal RC calibration value is placed at location 0x1FF by Microchip
; as a movlw k, where the k is a literal value.

	ORG     0x000             ; coding begins here
	movwf   OSCCAL            ; update register with factory cal value 

	



START	
	CLRF	GPIO			;CLEAR GPIO
	MOVLW	B'00011000'		;LOADING GPIO IN AND OUT
	TRIS	GPIO			;LOAD
	MOVLW	B'01000000'		;LOADING OPTION SO DRUM FIRES LIGHTS
	OPTION					;LOAD
	MOVLW	.255			;TURN OFF ALL LEDS
	MOVWF	GPIO			;LOAD
	MOVLW	.4				;LOADING REPEAT WITH 4  CHANGE THIS FOR MORE OR LESS REPEAT
	MOVWF	REPEAT			;LOAD

;************************FLAG CHECKING ROUTINE*******************************

FLAG_ROUTINE
	BTFSC	FLAG,1			;CHECKING FLAGS FOR JUMPS
	GOTO	ONE
	BTFSC	FLAG,2
	GOTO	TWO
	BTFSC	FLAG,3
	GOTO	THREE
	BTFSC	FLAG,4
	GOTO	FOUR
	BTFSC	FLAG,5
	GOTO	FIVE
	BTFSC	FLAG,6
	GOTO	SIX
	BTFSC	FLAG,7
	GOTO	SEVEN



ONE
	CLRF	FLAG			;CLEAR FLAG
	BCF		RED				;TURN ON RED
	CALL	DELAY			;CALL DELAY
	BSF		RED				;TURN OFF RED
	BCF		GREEN			;TURN ON GREEN
	CALL	DELAY			;CALL DELAY
	BSF		GREEN			;TURN OFF GREEN
	BCF		YELLOW			;TURN ON YELLOW
	CALL	DELAY			;CALL DELAY
	BSF		YELLOW			;TURN OFF YELLOW
	BCF		WHITE			;TURN ON WHITE
	CALL	DELAY			;CALL DELAY
	BSF		WHITE			;TURN OFF WHITE
	BSF		FLAG,2			;SET FLAG FOR NEXT ONE
	DECFSZ	REPEAT,1
	GOTO	ONE
	SLEEP					;SLEEP
	NOP						;DEBUGGER HELPER

TWO
	CLRF	FLAG			;CLEAR FLAG
	BCF		WHITE			;TURN ON WHITE
	CALL	DELAY			;CALL DELAY						
	BSF		WHITE			;TURN OFF WHITE
	BCF		YELLOW			;TURN ON YELLOW
	CALL	DELAY			;CALL DELAY
	BSF		YELLOW			;TURN OFF YELLOW
	BCF		GREEN			;TURN ON GREEN
	CALL	DELAY			;CALL DELAY
	BSF		GREEN			;TURN OFF GREEN
	BCF		RED				;TURN ON RED
	CALL	DELAY			;CALL DELAY
	BSF		RED				;TURN OFF RED
	BSF		FLAG,1			;SET FLAG FOR NEXT ONE
	DECFSZ	REPEAT,1
	GOTO	TWO
	SLEEP					;SLEEP
	NOP						;DEBUGGER HELPER

THREE		
	CLRF	FLAG			;CLEAR FLAG
	BCF		RED				;TURN ON RED
	CALL	DELAY			;CALL DELAY
	BSF		RED				;TURN OFF RED
	CALL	DELAY			;CALL DELAY
	DECFSZ	REPEAT,1		;DO 4 TIMES
	GOTO	THREE			;DO 40 TIMES
	BSF		FLAG,4			;SET FLAG FOR NEXT ONE
	SLEEP					;SLEEP
	NOP
FOUR
	CLRF	FLAG			;CLEAR FLAG
	BCF		GREEN			;TURN ON GREEN
	CALL	DELAY			;CALL DELAY
	BSF		GREEN			;TURN OFF GREEN
	CALL	DELAY			;CALL DELAY
	DECFSZ	REPEAT,1		;DO FOUR TIMES
	GOTO	FOUR			;DO 4 TIMES
	BSF		FLAG,5			;SET FLAG FOR NEXT ONE
	SLEEP					;SLEEP
	NOP						;DEBUGGER HELPER

FIVE
	CLRF	FLAG			;CLEAR FLAG
	BCF		YELLOW			;TURN ON YELLOW
	CALL	DELAY			;CALL DELAY
	BSF		YELLOW			;TURN OFF YELLOW
	CALL	DELAY			;CALL DELAY
	DECFSZ	REPEAT,1		;DO 4 TIMES
	GOTO	FIVE			;DO 4 TIMES
	BSF		FLAG,6			;SET FLAG FOR NEXT ONE
	SLEEP					;SLEEP
	NOP						;DEBUGGER HELPER

SIX
	CLRF	FLAG			;CLEAR FLAG
	BCF		WHITE			;TURN ON WHITE
	CALL	DELAY			;CALL DELAY
	BSF		WHITE			;TURN OFF WHITE
	CALL	DELAY			;CALL DELAY
	DECFSZ	REPEAT,1		;DO 4 TIMES
	GOTO	SIX				;DO 4 TIMES
	BSF		FLAG,7			;SET FLAG FOR NEXT ONE
	SLEEP					;SLEEP
	NOP						;DEBUGGER HELPER

SEVEN
	CLRF	FLAG			;CLEAR FLAG
	BCF		RED				;TURN ON RED
	CALL	DELAY			;CALL DELAY
	BSF		RED				;TURN OFF RED
	CALL	DELAY			;CALL DELAY
	BCF		GREEN			;TURN ON GREEN
	CALL	DELAY			;CALL DELAY
	BSF		GREEN			;TURN OFF GREEN
	CALL	DELAY			;CALL DELAY
	DECFSZ	REPEAT,1		;REPEAT
	GOTO	SEVEN			;JUMP BACK TO SEVEN
	BSF		FLAG,1			;SET FLAG FOR NEXT ONE
	SLEEP					;SLEEP
	NOP						;DEBUGGER HELPER


DELAY
	DECFSZ	DELAY1,1		;DELAY REGISTER
	GOTO	$-1		
	DECFSZ	DELAY2,1		;DELAY REGISTER
	GOTO	$-3
	MOVLW	.100			;CHANGE THIS FOR SHORTER OR LONGER DELAY OF LEDS
	MOVWF	DELAY2
	RETURN






	END                       ; directive 'end of program'

